@@ -1,7 +1,7 @@
 from typing import *
-import royalnet.commands as rc
 
-from ..version import semantic
+import pkg_resources
+import royalnet.commands as rc
 
 
 class RoyalpackCommand(rc.Command):
@@ -11,11 +11,15 @@ class RoyalpackCommand(rc.Command):
 
     syntax: str = ""
 
+    @property
+    def royalpack_version(self):
+        return pkg_resources.get_distribution("royalpack").version
+
     async def run(self, args: rc.CommandArgs, data: rc.CommandData) -> None:
         if __debug__:
             message = f"ℹ️ Royalpack [url=https://github.com/Steffo99/royalpack/]Unreleased[/url]\n"
         else:
-            message = f"ℹ️ Royalpack [url=https://github.com/Steffo99/royalpack/releases/tag/{semantic}]{semantic}[/url]\n"
+            message = f"ℹ️ Royalpack [url=https://github.com/Steffo99/royalpack/releases/tag/{self.royalpack_version}]{self.royalpack_version}[/url]\n"
         if "69" in semantic:
             message += "(Nice.)"
         await data.reply(message)
