@@ -1,25 +1,27 @@
 from typing import *
-from royalnet.constellation.api import *
+import royalnet.constellation.api as rca
 import logging
 
 
 log = logging.getLogger(__name__)
 
 
-class ApiDiscordPlayStar(ApiStar):
-    path = "/api/discord/play/v1"
-
-    summary = "Add a audio file to the RoyalQueue of a Discord Guild."
+class ApiDiscordPlayStar(rca.ApiStar):
+    path = "/api/discord/play/v2"
 
     parameters = {
-        "url": "The url of the audio file to add.",
-        "user": "The name to display in the File Added message.",
-        "guild_id": "The id of the guild owning the RoyalQueue to add the audio file to."
+        "post": {
+            "url": "The url of the audio file to add.",
+            "user": "The name to display in the File Added message.",
+            "guild_id": "The id of the guild owning the RoyalQueue to add the audio file to.",
+        }
     }
 
     tags = ["discord"]
 
-    async def api(self, data: ApiData) -> dict:
+    @rca.magic
+    async def post(self, data: rca.ApiData) -> dict:
+        """Add a audio file to the RoyalQueue of a Discord Guild."""
         url = data["url"]
         user = data.get("user")
         guild_id_str = data.get("guild_id")
@@ -27,7 +29,7 @@ class ApiDiscordPlayStar(ApiStar):
             try:
                 guild_id: Optional[int] = int(guild_id_str)
             except (ValueError, TypeError):
-                raise InvalidParameterError("'guild_id' is not a valid int.")
+                raise rca.InvalidParameterError("'guild_id' is not a valid int.")
         else:
             guild_id = None
         log.info(f"Received request to play {url} on guild_id {guild_id} via web")
