@@ -10,6 +10,8 @@ from .brawlhallatier import BrawlhallaTier
 from .brawlhallametal import BrawlhallaMetal
 from .brawlhallarank import BrawlhallaRank
 from .pollmood import PollMood
+from .updatable import Updatable
+from .oauth_refresh import oauth_refresh
 
 
 __all__ = [
@@ -26,4 +28,6 @@ __all__ = [
     "BrawlhallaRank",
     "BrawlhallaTier",
     "PollMood",
+    "Updatable",
+    "oauth_refresh",
 ]
